@@ -577,7 +577,8 @@ do_open (GnomeVFSMethod *method,
 	int flags;
 	char *server;
 	char *path;
-
+	char *end;
+	
 	LOCK_SAMBA();
 	
 	DEBUG_SMB (("do_open() %s mode %d\n",
@@ -600,6 +601,19 @@ do_open (GnomeVFSMethod *method,
 	path  =
 	  gnome_vfs_unescape_string (gnome_vfs_uri_get_path (uri),
 				     NULL);
+
+
+	/* Ignore .directory files */
+	if (path) {
+		end = strrchr (path, '/');
+		if (end && strcmp (end+1, ".directory")==0) {
+			g_free (server);
+			g_free (path);
+			UNLOCK_SAMBA ();
+			return GNOME_VFS_ERROR_NOT_FOUND;
+		}
+	}
+	
 	if (server == NULL) {
 		if (!path) {
 			g_free (server);
@@ -1114,22 +1128,35 @@ do_get_file_info (GnomeVFSMethod *method,
 {
 	char *server;
 	char *share;
+	char *end;
 
 	server =
 	  gnome_vfs_unescape_string (gnome_vfs_uri_get_host_name (uri),
 				     NULL);
 
-	/* Is this of the form smb:/// or smb:///workgroup
-	 */
-	if (server == NULL)
-		return root_info (method, uri,
-				  vfs_file_info, options,
-				  context);
-
 	share =
 	  gnome_vfs_unescape_string (gnome_vfs_uri_get_path (uri),
 				     NULL);
-	
+
+	/* Ignore .directory files */
+	if (share) {
+		end = strrchr (share, '/');
+		if (end && strcmp (end+1, ".directory")==0) {
+			g_free (server);
+			g_free (share);
+			return GNOME_VFS_ERROR_NOT_FOUND;
+		}
+	}
+		
+	/* Is this of the form smb:/// or smb:///workgroup
+	 */
+	if (server == NULL) {
+		g_free (share);
+		return root_info (method, uri,
+				  vfs_file_info, options,
+				  context);
+	}
+
 	/* Is this of the form smb://foo/ , where foo can be
 	 * a server and/or a workgroup */ 
 	if (share == NULL || share[0] == 0 ||
@@ -1166,6 +1193,36 @@ do_is_local (GnomeVFSMethod *method,
 
 
 {
+	const char *server;
+	const char *share;
+	const char *tmp;
+	const char *next_slash;
+
+	server = gnome_vfs_uri_get_host_name (uri);
+
+	/* Is this of the form smb:/// or smb:///workgroup
+	 */
+	if (server == NULL)
+		return TRUE;
+
+	share = gnome_vfs_uri_get_path (uri);
+	
+	/* Is this of the form smb://foo/ , where foo can be
+	 * a server and/or a workgroup */ 
+	if (share == NULL || share[0] == 0 ||
+	    (share[0] == '/' && share[1] == 0))
+		return TRUE;
+	
+	/* Is this a //workgroup/server/ ?
+	 */
+	tmp = share;
+	if (*tmp == '/')
+		tmp++;
+	
+	next_slash = strchr (tmp, '/');
+	if (next_slash == NULL || next_slash[1] == 0) 
+		return TRUE;
+
 	return FALSE;
 }
 
